@@ -1013,8 +1013,7 @@ post_process_multipart (struct MHD_PostProcessor *pp,
        * > generally be left blank, and implementations must ignore
        * > anything that appears before the first boundary delimiter
        * > line or after the last one.
-       */
-      (void) find_boundary (pp,
+       */(void) find_boundary (pp,
                             pp->boundary,
                             pp->blen,
                             &ioff,
@@ -1290,4 +1289,5 @@ MHD_destroy_post_processor (struct MHD_PostProcessor *pp)
   return ret;
 }
 
+
 /* end of postprocessor.c */
